@@ -1,13 +1,9 @@
-
 pkg_data <- new.env(parent = emptyenv())
 
 .onLoad <- function(libname, pkgname) {
-  utils::data(
-    pak_sitrep_data,
-    package = pkgname,
-    envir = environment(.onLoad)
-  )
-
+  if (Sys.getenv("DEVTOOLS_LOAD") == "pak") {
+    create_dev_lib()
+  }
   if (Sys.getenv("_R_CHECK_PACKAGE_NAME_", "") == "") {
     check_platform(libname, pkgname)
   }
@@ -17,7 +13,6 @@ pkg_data <- new.env(parent = emptyenv())
   if (worker == "") {
     ## In the main process
     fix_macos_path_in_rstudio()
-
   } else if (worker == "true") {
     ## In the worker process
     Sys.setenv("R_PKG_PKG_WORKER" = "false")
@@ -32,7 +27,6 @@ pkg_data <- new.env(parent = emptyenv())
     cainfo <- getOption("async_http_cainfo")
     if (is.null(cainfo) && ca_path != "") options(async_http_cainfo = ca_path)
     use_private_lib()
-
   } else {
     ## In a subprocess of a worker
     use_private_lib()
@@ -44,10 +38,14 @@ pkg_data <- new.env(parent = emptyenv())
 check_platform <- function(libname = dirname(find.package("pak")),
                            pkgname = "pak", data = pak_sitrep_data) {
   # Is this load_all()?
-  if (!file.exists(file.path(libname, pkgname, "help"))) return(TRUE)
+  if (!file.exists(file.path(libname, pkgname, "help"))) {
+    return(TRUE)
+  }
 
   # Is this during installation?
-  if (Sys.getenv("R_PACKAGE_DIR", "") != "") return(TRUE)
+  if (Sys.getenv("R_PACKAGE_DIR", "") != "") {
+    return(TRUE)
+  }
 
   current <- R.Version()$platform
   install <- data$platform
@@ -82,29 +80,39 @@ platform_match <- function(install, current) {
   arch_cur <- get_arch_from_platform(current)
 
   # OS must match in the first place
-  if (os_ins != os_cur) return(FALSE)
+  if (os_ins != os_cur) {
+    return(FALSE)
+  }
 
   # If it is Windows, then all should be good in general. Ideally we would
   # check if the current arch is really available.
   # both 32 bit or 64 bit
-  if (os_ins == "windows") return(TRUE)
+  if (os_ins == "windows") {
+    return(TRUE)
+  }
 
   # If it is macOS, then all should be good, still, but as a preparation
   # for arm, we check the arch
-  if (os_ins == "macos") return(arch_ins == arch_cur)
+  if (os_ins == "macos") {
+    return(arch_ins == arch_cur)
+  }
 
   # If it is Solaris, then arch must match. Btw. our 64 bit build has the
   # same platform string as the 32 bit build, which is probably a bug.
-  if (os_ins == "solaris") return(arch_ins == arch_cur)
+  if (os_ins == "solaris") {
+    return(arch_ins == arch_cur)
+  }
 
   # If it is Linux, then arch must match, if libc is musl, that's ok,
   # because that's probably our static build
   if (os_ins == "linux") {
-    if (arch_ins != arch_cur) return(FALSE)
+    if (arch_ins != arch_cur) {
+      return(FALSE)
+    }
     libc_ins <- get_libc_from_platform(install)
     libc_cur <- get_libc_from_platform(current)
     same <- !is.na(libc_ins) && !is.na(libc_cur) && libc_ins == libc_cur
-    return(same || identical(libc_ins,  "musl"))
+    return(same || identical(libc_ins, "musl") || is.na(libc_ins))
   }
 
   # Otherwise, the whole platform string must match. We might improve
@@ -114,10 +122,18 @@ platform_match <- function(install, current) {
 
 get_os_from_platform <- function(x) {
   pcs <- strsplit(x, "-", fixed = TRUE)[[1]]
-  if (pcs[3] == "mingw32") return("windows")
-  if (pcs[2] == "apple") return("macos")
-  if (pcs[3] == "linux") return("linux")
-  if (grepl("^solaris", pcs[3])) return("solaris")
+  if (pcs[3] == "mingw32") {
+    return("windows")
+  }
+  if (pcs[2] == "apple") {
+    return("macos")
+  }
+  if (pcs[3] == "linux") {
+    return("linux")
+  }
+  if (grepl("^solaris", pcs[3])) {
+    return("solaris")
+  }
   sub("[0-9.]*$", "", pcs[3])
 }
 
@@ -128,6 +144,8 @@ get_arch_from_platform <- function(x) {
 
 get_libc_from_platform <- function(x) {
   pcs <- strsplit(x, "-", fixed = TRUE)[[1]]
-  if (pcs[3] != "linux") return(NA_character_)
+  if (pcs[3] != "linux") {
+    return(NA_character_)
+  }
   pcs[4]
 }
